@@ -7,16 +7,30 @@
 #include <QObject>
 #include <QString>
 
+#include <KSvg/ImageSet>
+
+#include <qqmlintegration.h>
+
+class QJSEngine;
+class QQmlEngine;
+
+namespace KSvg
+{
+class Svg;
+};
+
 class UtilModel : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
     Q_PROPERTY(QString tzName READ getCurrentTimeZoneName CONSTANT)
     Q_PROPERTY(bool use24HourTime READ use24HourTime NOTIFY use24HourTimeChanged)
 
 public:
-    explicit UtilModel(QObject *parent = nullptr);
     static UtilModel *instance();
+    static UtilModel *create(QQmlEngine *qmlEngine, QJSEngine *jsEngine);
 
     Q_INVOKABLE QString getDefaultAlarmFileLocation();
 
@@ -34,10 +48,18 @@ public:
     Q_INVOKABLE qint64 msToSecondsPart(qint64 ms) const;
     Q_INVOKABLE qint64 msToSmallPart(qint64 ms) const; // hundredths of second
     Q_INVOKABLE QString displayTwoDigits(const qint64 &amount);
+    Q_INVOKABLE QString repeatFormat(int dayOfWeek) const;
+
+    Q_INVOKABLE void applyPlasmaImageSet(KSvg::Svg *svg);
 
 private:
+    explicit UtilModel(QObject *parent = nullptr);
+
     bool isLocale24HourTime() const;
 
 Q_SIGNALS:
     void use24HourTimeChanged();
+
+private:
+    KSvg::ImageSet *m_plasmaImageSet = nullptr;
 };
